@@ -1,3 +1,4 @@
+from eltyer_investing_algorithm_framework.configuration import constants
 from eltyer_investing_algorithm_framework.setup import create_app
 from eltyer_investing_algorithm_framework.utils.version import get_version
 from eltyer_investing_algorithm_framework.initializer \
@@ -7,7 +8,7 @@ from eltyer_investing_algorithm_framework.portfolio_manager \
 from eltyer_investing_algorithm_framework.order_executor \
     import EltyerOrderExecutor as OrderExecutor
 
-VERSION = (0, 4, 0, 'alpha', 0)
+VERSION = (0, 4, 1, 'alpha', 0)
 
 
 __all__ = [
@@ -15,5 +16,6 @@ __all__ = [
     "create_app",
     "Initializer",
     "PortfolioManager",
-    "OrderExecutor"
+    "OrderExecutor",
+    "constants"
 ]
